@@ -2,8 +2,9 @@ package MojoX::Plugin::AnyCache;
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
+has '_raw';
 has 'app';
 has 'backend';
 has 'config';
@@ -36,11 +37,26 @@ sub check_mode {
   die("Backend " . ref($self->backend) ." doesn't support synchronous requests") if !$cb && !$self->backend->support_sync;
 }
 
+sub raw {
+    my ($self) = @_;
+
+    my $clone = $self->new;
+
+    # Deep copy
+    $clone->app    ( $self->app     );
+    $clone->backend( $self->backend );
+    $clone->config ( $self->config  );
+
+    $clone->_raw(1);
+
+    return $clone;
+}
+
 sub get {
   my $cb = ref($_[-1]) eq 'CODE' ? pop : undef;
   my ($self, $key) = @_;
   $self->check_mode($cb);
-  if(my $serialiser = $self->backend->get_serialiser) {
+  if( !$self->_raw && (my $serialiser = $self->backend->get_serialiser)) {
     return $self->backend->get($key, sub { $cb->($serialiser->deserialise(@_)) }) if $cb;
     return $serialiser->deserialise($self->backend->get($key));
   } else {
@@ -53,7 +69,7 @@ sub set {
   my $cb = ref($_[-1]) eq 'CODE' ? pop : undef;
   my ($self, $key, $value, $ttl) = @_;
   $self->check_mode($cb);
-  if(my $serialiser = $self->backend->get_serialiser) {
+  if( !$self->_raw && (my $serialiser = $self->backend->get_serialiser)) {
     return $self->backend->set($key, $serialiser->serialise($value), $ttl, sub { $cb->(@_) }) if $cb;
     return $self->backend->set($key => $serialiser->serialise($value), $ttl);
   } else {
