@@ -13,7 +13,7 @@ sub get_serialiser {
 	my ($self) = @_;
 	if(!$self->serialiser && $self->config->{serialiser}) {
 		eval {
-			eval "require $self->config->{backend};";
+			eval "require $self->config->{serialiser};";
 			warn("Require failed: $@") if $self->config->{debug} && $@;
 			my $serialiser = $self->config->{serialiser}->new;
 			$serialiser->config($self->config);
@@ -30,4 +30,4 @@ sub incr { die("Must be overridden in backend module") };
 sub decr { die("Must be overridden in backend module") };
 sub del { die("Must be overridden in backend module") };
 
-1;
\ No newline at end of file
+1;
